# pyak-view—AppKit View—macOS only

View text in given font, using Apple’s AppKit (in Python).

It is called `pyak-view` after `hb-view` from _harfbuzz_.

Currently in somewhat experimental form.

Basic usage:

    pyak-view --font-file fontfile.otf ¡Hello!

Further command line help is available with

    pyak-view --help



## INSTALLATION

From PyPI:

    python -m pip install pyak-view

From a clone or copy of this repo:

    python -m pip install -U .


# END
